# Advanced

```{note}
Work In Progress
```

In this section, we will go into detail and see how `PytCube` works. A better understanding of how PytCube functions helps to better grasp its limitations, as well as how to configure it to achieve the best possible performance.

```{toctree}
:maxdepth: 1

setup
batching
indexing
optimization
```